""" This module provides functions to convert a PDF to text. """


class Converter:
    """ A simple converter for converting PDFs to text """

    def convert(self, path):
        """
        convert the givern PDF to text.

        Parameters:
        path(str): the path to a PDF file.

        Returns:
        str: The content of PDF file as text.
        """
        print("PDF2text")
